# Copyright 2012 Nebula, Inc.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.
try:
    import memcache

    class HorizonClient(memcache.Client):

        def __init__(self, *args, **kwargs):
            self.server_retries = kwargs.pop("server_retries", 10)
            super(HorizonClient, self).__init__(*args, **kwargs)

        def _get_server(self, key):
            if isinstance(key, tuple):
                serverhash, key = key
            else:
                serverhash = memcache.serverHashFunction(key)

            if not self.buckets:
                return None, None

            for i in range(self.server_retries):
                server = self.buckets[serverhash % len(self.buckets)]
                if server.connect():
                    return server, key
                serverhash = memcache.serverHashFunction(
                    str(serverhash) + str(i))
            return None, None
except ImportError:
    pass
